translate.filters.pofilter.pocheckfilter

Package translate :: Package filters :: Module pofilter :: Class pocheckfilter |
[hide private]
[frames] | no frames]

# Class pocheckfilter

source code

Instance Methods | [hide private]
__init__(self, options, checkerclasses=None, checkerconfig=None) builds a checkfilter using the given checker (a list is allowed too) | source code
getfilterdocs(self) lists the docs for filters available on checker... | source code
filterunit(self, unit) runs filters on an element | source code
filterfile(self, transfile) Runs filters on a translation store object. | source code

Method Details | [hide private]

### filterfile(self, transfile) | source code
Runs filters on a translation store object. Parameters: transfile. A translation store object. Return value: A new translation store object with the results of the filter included.